GraphInspector class

The GraphInspector class is used to inspect the modules and their dependencies in the application. It creates a graph representation of the modules and their dependencies.

Inheritance

Constructors

GraphInspector(SerializedGraph graph, ModulesContainer _container)
Creates a new instance of GraphInspector.
const

Properties

graph SerializedGraph
The graph that will be used to display the modules and their dependencies.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

inspectModules([Iterable<ModuleScope>? modules]) → void
Inspects the modules in the application and adds them to the graph.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the GraphInspector to a JSON object. This is used to display the graph in the inspector.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited