toJson method
Converts the GraphInspector to a JSON object. This is used to display the graph in the inspector.
Implementation
Map<String, dynamic> toJson() {
return graph.toJson();
}
Converts the GraphInspector to a JSON object. This is used to display the graph in the inspector.
Map<String, dynamic> toJson() {
return graph.toJson();
}