all property
Map
get
all
This method is used to get all the values from the session.
Implementation
Map<dynamic, dynamic> get all =>
Map<dynamic, dynamic>.fromEntries(_original.entries);
This method is used to get all the values from the session.
Map<dynamic, dynamic> get all =>
Map<dynamic, dynamic>.fromEntries(_original.entries);